<?php
/*
Plugin Name: Minotar
Plugin URI: http://minotar.net/
Description: Enables Minecraft skins to be used as avatars.
Author: <a href="http://axxim.net/">Luke Strickland</a> and Joel Bergroth
Version: 0.2
*/

/*  Copyright 2011

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

//This is executed when Minotar is enabled from the Plugins page.
register_activation_hook(__FILE__, 'minotar_activation');

function minotar_activation() {
	
	//Set Minotar to be the default avatar
	update_option( 'avatar_default', 'minotar' );
	
}


//This is executed when Minotar is deactivated or uninstalled 
register_deactivation_hook(__FILE__, 'minotar_deactivation' );

function minotar_deactivation() {

	//Set Mystery Man to be the default avatar
	update_option( 'avatar_default', 'mystery' );
	
}

register_uninstall_hook(__FILE__, 'minotar_uninstall') ;

function minotar_uninstall() {

	//Set Mystery Man to be the default avatar
	update_option( 'avatar_default', 'mystery' );
	
}


//Adds Minotar to the avatar list.
add_filter( 'avatar_defaults' , 'add_minotar_avatar' );

function add_minotar_avatar ( $avatar_defaults ) {

	$avatar_defaults['minotar'] = 'Minotar';
	
	return $avatar_defaults;
}


//Extends get_avatar function to include Minotar
add_filter( 'get_avatar', 'get_minotar_avatar', 1, 5 );

function get_minotar_avatar( $avatar, $id_or_email, $size, $default, $alt ) {
	
	if( $default == 'minotar' ) {
	
		//Alternative text
		if ( false === $alt)
			$safe_alt = '';
		else
			$safe_alt = esc_attr( $alt );
	
		//Get username
		if ( is_numeric($id_or_email) ) {
			$id = (int) $id_or_email;
			$user = get_userdata($id);
			if ( $user )
			$username = $user->user_login;
		} elseif ( is_object($id_or_email) ) {

			if ( !empty($id_or_email->user_id) ) {
				$id = (int) $id_or_email->user_id;
				$user = get_userdata($id);
				if ( $user)
					$username = $user->user_login;
			} elseif ( !empty($id_or_email->comment_author) ) {
				$username = $id_or_email->comment_author;
			}
		} else {
			require_once(ABSPATH . WPINC . '/ms-functions.php');
			$id = get_user_id_from_string($id_or_email);
			$user = get_userdata($id);
			$username = $user->user_login;
		}
		
		$minotar = 'http://minotar.net/avatar/'.$username.'/'.$size.'/';
		
		$avatar = "<img alt='".$safe_alt."' src='".$minotar."' class='avatar avatar-".$size." photo' height='".$size."' width='".$size."' />";
		
	}
	
	return $avatar;
}

?>